# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        "Agent celny",
        "Agent firmy inwestycyjnej",
        "Agent literacki",
        "Agent ubezpieczeniowy",
        "Agronom",
        "Aktor",
        "Aktor dziecięcy",
        "Aktor głosowy",
        "Aktuariusz",
        "Animator kultury",
        "Ankieter",
        "Antykwariusz",
        "Arborysta",
        "Archeolog",
        "Architekt krajobrazu",
        "Architekt wnętrz",
        "Archiwista",
        "Artysta-rezydent",
        "Astronom",
        "Audytor efektywności energetycznej",
        "Babcia klozetowa",
        "Bankowiec",
        "Barista",
        "Barman",
        "Bibliotekarz",
        "Bibliotekarz dyplomowany",
        "Biegły rewident",
        "Brakarz",
        "Broker",
        "Broker informacji",
        "Broker ubezpieczeniowy",
        "Certyfikator energetyczny",
        "Charakteryzator",
        "Detektyw",
        "Deweloper budowlany",
        "Doker",
        "Doradca finansowy",
        "Doradca inwestycyjny",
        "Doradca podatkowy w Polsce",
        "Doradca ubezpieczeniowy",
        "Drwal",
        "Dubler",
        "Dyplomata",
        "Dyrektor artystyczny",
        "Dyrektor finansowy",
        "Dyrektor kreatywny",
        "Dziennikarz",
        "Dżokej",
        "Ebenista",
        "Ekonomista",
        "Ekwilibrystyka",
        "Elektromonter pomiarów",
        "Ergonomista",
        "Fasowacz",
        "Finansista",
        "Fotoreporter",
        "Geodeta",
        "Geolog",
        "Główny księgowy",
        "Grabarz",
        "Handlarz",
        "Hostessa",
        "Hutnik",
        "Hycel",
        "Hydraulik",
        "Iluzjonista",
        "Inscenizator",
        "Instruktor",
        "Integrator automatyki",
        "Intendent",
        "Inżynier",
        "Inżynier budownictwa",
        "Kasjer biletowy",
        "Katecheta",
        "Kawalkator",
        "Kawiarka",
        "Kelner",
        "Kierowca",
        "Kiper",
        "Klechdarz",
        "Konferansjer",
        "Koniarze",
        "Konserwator zabytków",
        "Konsjerż",
        "Konstruktor",
        "Konsultant",
        "Konsultant ślubny",
        "Kontroler biletów",
        "Kornak",
        "Kosmonauta",
        "Kostiumograf",
        "Kosztorysant",
        "Kowboj",
        "Krojczy",
        "Krupier",
        "Ksiądz",
        "Księgowy",
        "Kuk",
        "Kupiec",
        "Kurator sądowy",
        "Kurator sztuki",
        "Kurier",
        "Kurier rowerowy",
        "Lalkarz",
        "Leśniczy",
        "Liczmen",
        "Likwidator szkód",
        "Listonosz",
        "Łącznik",
        "Makler giełd towarowych",
        "Makler morski",
        "Makler nadzorujący",
        "Makler papierów wartościowych",
        "Marketingowiec",
        "Marynarz",
        "Masztalerz",
        "Menedżer kultury",
        "Meteorolog",
        "Mim",
        "Model",
        "Modelka dużych rozmiarów",
        "Motorniczy",
        "Nadleśniczy",
        "Nauczyciel",
        "Nauczyciel akademicki",
        "Naukowiec",
        "Niania",
        "Oceanonauta",
        "Ochroniarz",
        "Pakowacz",
        "Palacz",
        "Perfumiarz",
        "Pisarz",
        "Plastyk",
        "Podleśniczy",
        "Poganiacz",
        "Pokojówka",
        "Politolog",
        "Polityk",
        "Portier",
        "Pośrednik finansowy",
        "Pośrednik ubezpieczeniowy",
        "Pośrednik w obrocie nieruchomościami",
        "Pracownicy uczelni w Polsce",
        "Pracownik socjalny",
        "Prezenter",
        "Producent wykonawczy",
        "Projektant gier komputerowych",
        "Przedstawiciel handlowy",
        "Przewodnik turystyczny",
        "Psiarz",
        "Psycholog",
        "Pucybut",
        "Rachmistrz",
        "Ratownik",
        "Ratownik przedmedyczny",
        "Redaktor",
        "Redaktor merytoryczny",
        "Redaktor naukowy",
        "Redaktor techniczny",
        "Rekwizytor",
        "Reporter wojenny",
        "Reżyser",
        "Robotnik",
        "Rolnik",
        "Rybak",
        "Rzecznik prasowy",
        "Rzeczoznawca",
        "Rzeczoznawca budowlany",
        "Rzeczoznawca majątkowy",
        "Rzeczoznawca samochodowy",
        "Salowa",
        "Satyryk",
        "Scenarzysta",
        "Scenograf",
        "Służący",
        "Sprzątacz",
        "Sprzedawca",
        "Stajenny",
        "Strażak",
        "Sufler",
        "Supermodelka",
        "Syndyk",
        "Syndyk licencjonowany",
        "Szatniarz",
        "Szczurołap",
        "Szlifierz",
        "Sztygar",
        "Taksówkarz",
        "Technik awionik",
        "Technik budownictwa",
        "Technik elektronik",
        "Technik handlowiec",
        "Technik kelner",
        "Technik mechanik",
        "Technik mechanik lotniczy",
        "Technik mechanik okrętowy",
        "Technik nawigator morski",
        "Technik ochrony środowiska",
        "Technik technologii drewna",
        "Technik weterynarii",
        "Technik żywienia i gospodarstwa domowego",
        "Teksturator",
        "Terapeuta",
        "Terminolog",
        "Tłumacz",
        "Tłumacz literacki",
        "Tłumacz przysięgły",
        "Tokarz",
        "Trener",
        "Trener personalny",
        "Urbanista",
        "Lekarz weterynarii",
        "Wydawca",
        "Zarządca nieruchomości",
        "Zoopsycholog",
        "Żołnierz",
        "Żongler",
    ]
