# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


# Taiwan jobs from
# http://www.104.com.tw/public/function01/utf8/jsonJobCat.js
# on Fri May 20 23:13:46 CST 2016
class Provider(BaseProvider):
    jobs = [
        'BIOS工程師',
        'CAD／CAM工程師',
        'CNC機台操作人員',
        'CNC電腦程式編排人員',
        'EMC／電子安規工程師',
        'FAE工程師',
        'IC佈局工程師',
        'IC封裝／測試工程師',
        'ISO／品保人員',
        'Internet程式設計師',
        'LCD製程工程師',
        'LCD設備工程師',
        'MES工程師',
        'MIS程式設計師',
        'MIS／網管主管',
        'OP／旅行社人員',
        'PCB佈線工程師',
        'PCB技術人員',
        'RF通訊工程師',
        'SMT工程師',
        '一般動物飼育工作者',
        '不動產產權審核／估價師',
        '不動產經紀人',
        '不動產／商場開發人員',
        '中等學校教師',
        '中醫師',
        '中餐廚師',
        '主持人',
        '主管特別助理',
        '主辦會計',
        '人力資源主管',
        '人力資源人員',
        '人力資源助理',
        '人力／外勞仲介',
        '代書／地政士',
        '估算人員',
        '作曲家',
        '作業員／包裝員',
        '保全人員／警衛',
        '保全技術人員',
        '保安服務工作',
        '保稅人員',
        '保險業務／經紀人',
        '倉儲物流人員',
        '倉管',
        '催收人員',
        '傳播媒體企劃人員',
        '傳銷人員',
        '儲備幹部',
        '光學工程師',
        '光電工程師',
        '光電工程研發主管',
        '內業工程師',
        '公共衛生人員',
        '公共衛生醫師',
        '公家機關人員',
        '券商後線人員',
        '副教授',
        '加油員',
        '助教',
        '助理工程師',
        '助理教授',
        '勞工安全衛生管理人員',
        '勞工安全衛生管理師',
        '包裝設計',
        '化學工程研發人員',
        '化學研究員',
        '化工化學工程師',
        '升學補習班老師',
        '半導體工程師',
        '半導體製程工程師',
        '半導體設備工程師',
        '印前製作／印刷技術人員',
        '可靠度工程師',
        '吊車／起重機設備操作員',
        '呼吸治療師',
        '品牌宣傳及媒體公關',
        '品管／品保主管',
        '品管／品保工程師',
        '品管／檢驗人員',
        '哲學／歷史／政治研究人員',
        '售票／收銀人員',
        '商業設計',
        '商標／專利人員',
        '噴漆人員',
        '國內業務主管',
        '國內業務人員',
        '國外業務主管',
        '國外業務人員',
        '國小學校教師',
        '國貿人員',
        '圖書資料管理人員',
        '土地開發人員',
        '土木技師／土木工程師',
        '地勤人員',
        '地質與地球科學研究員',
        '塑膠射出技術人員',
        '塑膠模具技術人員',
        '塗裝技術人員',
        '壓鑄模具技術人員',
        '外務／快遞／送貨',
        '多媒體動畫設計師',
        '多媒體開發主管',
        '大樓管理員',
        '大貨車司機',
        '天文研究員',
        '太陽能技術工程師',
        '娛樂事業人員',
        '媒體公關／宣傳採買',
        '安全／衛生檢驗人員',
        '安心服務員',
        '安親班老師',
        '客戶服務主管',
        '客戶服務人員',
        '室內設計／裝潢人員',
        '家事服務人員',
        '家庭代工',
        '實驗化驗人員',
        '寵物美容專業人員',
        '專案業務主管',
        '專案管理主管',
        '專案管理師',
        '專科護理師',
        '導播',
        '導演',
        '導遊',
        '小客車司機',
        '小貨車司機',
        '居家服務督導員',
        '展場／櫥窗佈置人員',
        '工務人員／助理',
        '工商登記服務人員',
        '工地監工／主任',
        '工廠主管',
        '工業工程師／生產線規劃',
        '工業設計',
        '工程助理',
        '工程研發主管',
        '工程配管繪圖',
        '工讀生',
        '市場調查／市場分析',
        '平面設計／美編人員',
        '幼教班老師',
        '店長／賣場管理人員',
        '廠務',
        '廠務助理',
        '廣告AE業務人員',
        '廣告企劃主管',
        '廣告文案／企劃',
        '廣告設計',
        '建築師',
        '建築物清潔工',
        '建築物電力系統維修工',
        '建築設計／繪圖人員',
        '影片製作技術人員',
        '律師',
        '復建技術師',
        '微機電工程師',
        '心理學研究人員',
        '志工人員',
        '志願役軍官／士官／士兵',
        '應用科學研究員',
        '成本會計',
        '手工包裝工',
        '才藝類老師',
        '打版人員',
        '技術文件／說明書編譯',
        '按摩／推拿師',
        '排版人員',
        '採購主管',
        '採購人員',
        '採購助理',
        '推土機設備操作員',
        '播音／配音人員',
        '攝影助理',
        '攝影師',
        '放射性設備使用技術員',
        '救生員',
        '教保員',
        '教授',
        '教育訓練人員',
        '整體造型師',
        '數位IC設計工程師',
        '數學研究員',
        '數理補習班老師',
        '文件管理師',
        '文編／校對／文字工作者',
        '旅遊休閒類主管',
        '日式廚師',
        '日文翻譯／口譯人員',
        '星象占卜人員',
        '景觀設計師',
        '會計師',
        '服裝／皮包／鞋類設計',
        '木工',
        '材料研發人員',
        '板金技術員',
        '林木伐運工作者',
        '染整技術人員',
        '查帳／審計人員',
        '核保／保險內勤人員',
        '業務助理',
        '業務支援工程師',
        '樂器製造員',
        '模特兒',
        '機械加工技術人員',
        '機械工程師',
        '機械操作員',
        '機械裝配員',
        '機械設計／繪圖人員',
        '機構工程師',
        '機電技師／工程師',
        '櫃檯接待人員',
        '氣象研究員',
        '水保工程師',
        '水保技師',
        '水利工程師',
        '水產養殖工作者',
        '水電工',
        '水電工程師',
        '水電工程繪圖人員',
        '汽車美容人員',
        '汽車銷售人員',
        '汽車／機車引擎技術人員',
        '汽車／機車技術維修人員',
        '沖壓模具技術人員',
        '油漆工',
        '治療師',
        '法務人員',
        '法務助理',
        '法務／智財主管',
        '法律專業人員',
        '泥水小工',
        '泥水工',
        '洗碗人員',
        '活動企劃人員',
        '派報生／傳單派送',
        '消防員',
        '消防專業人員',
        '混凝土工',
        '清潔工',
        '測試人員',
        '演員',
        '演奏家',
        '演算法開發工程師',
        '焊接及切割技術員',
        '照顧指導員',
        '照顧服務員',
        '熱傳工程師',
        '燈光／音響師',
        '營建主管',
        '營建構造工',
        '營造工程師',
        '營運管理師',
        '營養師',
        '牙醫助理',
        '牙醫師',
        '物理治療師',
        '物理研究員',
        '物管／資材',
        '特殊工程師',
        '特殊教育教師',
        '特用化學工程師',
        '獸醫師',
        '珠寶及貴金屬技術員',
        '珠心算老師',
        '理賠人員',
        '環境工程師',
        '生命禮儀師',
        '生物學專業與研究',
        '生物科技研發人員',
        '生產技術／製程工程師',
        '生產管理主管',
        '生產設備工程師',
        '生管',
        '生管助理',
        '生鮮人員',
        '產品事業處主管',
        '產品企劃主管',
        '產品企劃開發人員',
        '產品售後技術服務',
        '產品管理師',
        '產品維修人員',
        '產品行銷人員',
        '病理藥理研究人員',
        '發包人員',
        '發行企劃／出版人員',
        '砌磚工',
        '研究人員',
        '研究助理',
        '硬體工程研發主管',
        '硬體測試工程師',
        '硬體研發工程師',
        '社工人員',
        '社會／人類學研究人員',
        '秘書',
        '稅務人員',
        '稽核人員',
        '空服員',
        '空調冷凍技術人員',
        '節目助理',
        '節目製作人員',
        '粉末冶金模具技術人員',
        '精密儀器製造工',
        '精密拋光技術人員',
        '系統整合／ERP專案師',
        '系統維護／操作人員',
        '紡織化學工程師',
        '紡織工務',
        '結構技師',
        '統計學研究員',
        '統計精算人員',
        '經營管理主管',
        '網站行銷企劃',
        '網路安全分析師',
        '網路管理工程師',
        '網頁設計師',
        '線切割技術員',
        '總務主管',
        '總務人員',
        '總幹事',
        '總機人員',
        '織品設計',
        '美姿美儀人員',
        '美容工作者',
        '美容類助理',
        '美甲彩繪師',
        '美療／芳療師',
        '美術老師',
        '美術設計',
        '美髮工作者',
        '美髮類助理',
        '翻譯／口譯人員',
        '聲學／噪音工程師',
        '聲樂家',
        '職能治療師',
        '股務人員',
        '自動控制工程師',
        '舞蹈指導與舞蹈家',
        '船務／押匯／報關人員',
        '船長／大副／船員',
        '花藝／園藝人員',
        '英文翻譯／口譯人員',
        '藝術品／珠寶鑑價／拍賣顧問',
        '藝術指導／總監',
        '藥學助理',
        '藥師',
        '融資／信用業務人員',
        '行政主管',
        '行政人員',
        '行政助理',
        '行銷企劃主管',
        '行銷企劃人員',
        '行銷企劃助理',
        '補習班導師／管理人員',
        '補習班老師',
        '製鞋類人員',
        '西餐廚師',
        '西點／蛋糕師',
        '視聽工程類人員',
        '計程車司機',
        '記帳／出納／一般會計',
        '記者／採編',
        '設計助理',
        '診所助理',
        '語文補習班老師',
        '語言治療師',
        '調酒師／吧台人員',
        '調音技術員',
        '講師',
        '護理師',
        '財務分析人員',
        '財務或會計主管',
        '財務會計助理',
        '資料庫管理人員',
        '資料輸入人員',
        '資材主管',
        '資源回收人員',
        '資訊助理人員',
        '資訊專業人員',
        '資訊設備管制人員',
        '車床人員',
        '車縫／裁縫類人員',
        '軟韌體測試工程師',
        '軟體專案主管',
        '軟體專案管理師',
        '軟體設計工程師',
        '農工業用機器裝修工',
        '農林業設備操作員',
        '農藝作物栽培工作者',
        '農藝／畜產研究人員',
        '通信測試維修人員',
        '通訊工程研發主管',
        '通訊軟體工程師',
        '通路開發人員',
        '連鎖店管理人員',
        '遊戲企劃人員',
        '運動教練',
        '運輸交通專業人員',
        '運輸物流類主管',
        '都市／交通規劃人員',
        '醫事放射師',
        '醫事檢驗師',
        '醫師',
        '醫療人員',
        '醫療器材研發工程師',
        '醫療從業人員',
        '醫療設備控制人員',
        '醫藥業務代表',
        '醫藥研發人員',
        '醫院行政管理人員',
        '量測／儀校人員',
        '金屬建材架構人員',
        '金融交易員',
        '金融專業主管',
        '金融承銷員',
        '金融營業員',
        '金融理財專員',
        '金融研究員',
        '銀行辦事員',
        '銑床人員',
        '鍋爐操作技術人員',
        '鐵路車輛駕駛員',
        '鑄造／鍛造模具技術人員',
        '門市／店員／專櫃人員',
        '防水施工人員',
        '防火及建築檢驗人員',
        '零件工程師',
        '雷射操作技術員',
        '電信及電力線路架設工',
        '電信／通訊系統工程師',
        '電台工作人員',
        '電子商務技術主管',
        '電子工程師',
        '電子產品系統工程師',
        '電子設備裝修工',
        '電機工程技術員',
        '電機技師／工程師',
        '電機裝修工',
        '電機設備裝配員',
        '電源工程師',
        '電玩程式設計師',
        '電腦系統分析師',
        '電腦組裝／測試',
        '電腦繪圖人員',
        '電腦補習班老師',
        '電話及電報機裝修工',
        '電話客服類人員',
        '電話行銷人員',
        '電鍍／表面處理技術人員',
        '韌體設計工程師',
        '音樂家',
        '音樂老師',
        '領班',
        '領隊',
        '類廚師',
        '類比IC設計工程師',
        '類講師',
        '顧問人員',
        '飛安人員',
        '飛機裝修工',
        '飛行機師',
        '食品研發人員',
        '食品衛生管理師',
        '飯店工作人員',
        '飯店餐廳主管',
        '餐廚助手',
        '餐飲服務生',
        '駐校代表',
        '驗光師',
        '麵包師',
        '麻醉醫師',
    ]
