# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as LoremProvider


class Provider(LoremProvider):
    word_connector = ''
    word_list = (
        u'一个',
        u'我们',
        u'时间',
        u'中国',
        u'可以',
        u'公司',
        u'没有',
        u'信息',
        u'下载',
        u'软件',
        u'注册',
        u'自己',
        u'产品',
        u'工作',
        u'论坛',
        u'企业',
        u'这个',
        u'他们',
        u'管理',
        u'已经',
        u'问题',
        u'内容',
        u'使用',
        u'进行',
        u'市场',
        u'服务',
        u'如果',
        u'系统',
        u'技术',
        u'发展',
        u'现在',
        u'作者',
        u'就是',
        u'网络',
        u'提供',
        u'相关',
        u'我的',
        u'文章',
        u'方式',
        u'电话',
        u'发表',
        u'所有',
        u'时候',
        u'因为',
        u'北京',
        u'有限',
        u'公司',
        u'什么',
        u'还是',
        u'开始',
        u'本站',
        u'发布',
        u'自己',
        u'支持',
        u'在线',
        u'国家',
        u'生活',
        u'联系',
        u'积分',
        u'主题',
        u'所以',
        u'不能',
        u'的人',
        u'上海',
        u'中心',
        u'世界',
        u'游戏',
        u'需要',
        u'价格',
        u'用户',
        u'通过',
        u'要求',
        u'不是',
        u'免费',
        u'个人',
        u'但是',
        u'地址',
        u'网站',
        u'情况',
        u'最后',
        u'设计',
        u'同时',
        u'这些',
        u'活动',
        u'手机',
        u'推荐',
        u'一些',
        u'主要',
        u'大家',
        u'发现',
        u'目前',
        u'文件',
        u'你的',
        u'不过',
        u'评论',
        u'生产',
        u'美国',
        u'图片',
        u'经济',
        u'功能',
        u'国际',
        u'的是',
        u'选择',
        u'其他',
        u'这样',
        u'会员',
        u'环境',
        u'来自',
        u'日期',
        u'成为',
        u'他的',
        u'最新',
        u'专业',
        u'一下',
        u'人员',
        u'任何',
        u'教育',
        u'资料',
        u'状态',
        u'都是',
        u'点击',
        u'为了',
        u'不会',
        u'出现',
        u'知道',
        u'社会',
        u'名称',
        u'而且',
        u'介绍',
        u'音乐',
        u'等级',
        u'可能',
        u'这种',
        u'建设',
        u'朋友',
        u'虽然',
        u'电子',
        u'资源',
        u'看到',
        u'精华',
        u'电影',
        u'如何',
        u'新闻',
        u'阅读',
        u'安全',
        u'全国',
        u'只有',
        u'回复',
        u'大学',
        u'学生',
        u'学习',
        u'关于',
        u'项目',
        u'不同',
        u'以及',
        u'有关',
        u'那么',
        u'开发',
        u'还有',
        u'只是',
        u'非常',
        u'研究',
        u'广告',
        u'首页',
        u'方法',
        u'希望',
        u'地方',
        u'也是',
        u'单位',
        u'怎么',
        u'应该',
        u'今天',
        u'以上',
        u'更新',
        u'帖子',
        u'显示',
        u'能力',
        u'电脑',
        u'记者',
        u'查看',
        u'位置',
        u'不要',
        u'由于',
        u'无法',
        u'详细',
        u'投资',
        u'是一',
        u'一般',
        u'进入',
        u'发生',
        u'这里',
        u'感觉',
        u'更多',
        u'你们',
        u'的话',
        u'起来',
        u'标准',
        u'一样',
        u'认为',
        u'女人',
        u'那个',
        u'设备',
        u'搜索',
        u'之后',
        u'然后',
        u'学校',
        u'销售',
        u'组织',
        u'说明',
        u'提高',
        u'为什',
        u'作品',
        u'或者',
        u'喜欢',
        u'东西',
        u'方面',
        u'简介',
        u'必须',
        u'经营',
        u'科技',
        u'作为',
        u'其中',
        u'运行',
        u'工程',
        u'解决',
        u'操作',
        u'经验',
        u'地区',
        u'重要',
        u'直接',
        u'登录',
        u'合作',
        u'结果',
        u'影响',
        u'这是',
        u'行业',
        u'对于',
        u'表示',
        u'程序',
        u'包括',
        u'留言',
        u'规定',
        u'处理',
        u'男人',
        u'各种',
        u'部门',
        u'数据',
        u'具有',
        u'商品',
        u'系列',
        u'大小',
        u'因此',
        u'关系',
        u'可是',
        u'比较',
        u'文化',
        u'一直',
        u'法律',
        u'这么',
        u'您的',
        u'城市',
        u'分析',
        u'基本',
        u'最大',
        u'类别',
        u'两个',
        u'日本',
        u'得到',
        u'一次',
        u'继续',
        u'成功',
        u'她的',
        u'责任',
        u'深圳',
        u'业务',
        u'欢迎',
        u'加入',
        u'能够',
        u'觉得',
        u'部分',
        u'中文',
        u'根据',
        u'人民',
        u'政府',
        u'控制',
        u'其实',
        u'之间',
        u'一种',
        u'威望',
        u'实现',
        u'语言',
        u'出来',
        u'谢谢',
        u'社区',
        u'品牌',
        u'是否',
        u'工具',
        u'完全',
        u'决定',
        u'很多',
        u'网上',
        u'事情',
        u'今年',
        u'国内',
        u'以后',
        u'制作',
        u'浏览',
        u'过程',
        u'完成',
        u'类型',
        u'来源',
        u'质量',
        u'有些',
        u'一起',
        u'当然',
        u'汽车',
        u'一点',
        u'帮助',
        u'增加',
        u'历史',
        u'以下',
        u'不断',
        u'应用',
        u'那些',
        u'密码',
        u'计划',
        u'如此',
        u'次数',
        u'到了',
        u'拥有',
        u'孩子',
        u'原因',
        u'参加',
        u'只要',
        u'报告',
        u'当前',
        u'客户',
        u'正在',
        u'注意',
        u'标题',
        u'空间',
        u'一定',
        u'一切',
        u'特别',
        u'全部',
        u'准备',
    )
